==> cartography-0.103.0rc1.tar.gz: cartography-0.103.0rc1/tests/data/snipeit/users.py <==
USERS = {
    "company_a": [
        {
            "id": 1,
            "avatar": "https://develop.snipeitapp.com/uploads/avatars/1.jpg",
            "name": "Admin User",
            "first_name": "Admin",
            "last_name": "User",
            "username": "admin",
            "remote": False,
            "locale": "en-US",
            "employee_num": "12832",
            "manager": None,
            "jobtitle": "Occupational Therapist Aide",
            "vip": False,
            "phone": "+1.234.432.8715",
            "website": None,
            "address": "703 Jeramy Parkway Apt. 582\nTitusfurt, SC 30323",
            "city": "South Keven",
            "state": "MT",
            "country": "Tajikistan",
            "zip": "22367",
            "email": "mcarter@example.net",
            "department": {
                "id": 3,
                "name": "Marketing",
            },
            "location": None,
            "notes": "Created by DB seeder",
            "permissions": {
                "superuser": "1",
            },
            "activated": True,
            "autoassign_licenses": True,
            "ldap_import": False,
            "two_factor_enrolled": False,
            "two_factor_optin": False,
            "assets_count": 7,
            "licenses_count": 1,
            "accessories_count": 0,
            "consumables_count": 0,
            "company": {
                "id": 2,
                "name": "Lind, Schroeder and Pacocha",
            },
            "created_by": None,
            "created_at": {
                "datetime": "2024-04-26 09:42:05",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "updated_at": {
                "datetime": "2024-04-26 09:42:05",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "start_date": None,
            "end_date": None,
            "last_login": None,
            "deleted_at": None,
            "available_actions": {
                "update": True,
                "delete": False,
                "clone": True,
                "restore": False,
            },
            "groups": None,
        },
        {
            "id": 2,
            "avatar": "https://develop.snipeitapp.com/uploads/avatars/2.jpg",
            "name": "Snipe E. Head",
            "first_name": "Snipe E.",
            "last_name": "Head",
            "username": "snipe",
            "remote": False,
            "locale": "en-US",
            "employee_num": "30845",
            "manager": None,
            "jobtitle": "Transportation Worker",
            "vip": False,
            "phone": "785-362-4759",
            "website": None,
            "address": "7535 Bruen Junctions\nNorth Ceciliachester, VA 80961-3508",
            "city": "Breitenbergborough",
            "state": "ND",
            "country": "Gambia",
            "zip": "67260-1176",
            "email": "snipe@snipe.net",
            "department": {
                "id": 6,
                "name": "Dept of Silly Walks",
            },
            "location": None,
            "notes": "Created by DB seeder",
            "permissions": {
                "superuser": "1",
            },
            "activated": True,
            "autoassign_licenses": True,
            "ldap_import": False,
            "two_factor_enrolled": False,
            "two_factor_optin": False,
            "assets_count": 6,
            "licenses_count": 1,
            "accessories_count": 0,
            "consumables_count": 0,
            "company": {
                "id": 1,
                "name": "Beier, Schumm and Upton",
            },
            "created_by": None,
            "created_at": {
                "datetime": "2024-04-26 09:42:05",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "updated_at": {
                "datetime": "2024-04-26 09:42:05",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "start_date": None,
            "end_date": None,
            "last_login": None,
            "deleted_at": None,
            "available_actions": {
                "update": True,
                "delete": False,
                "clone": True,
                "restore": False,
            },
            "groups": None,
        },
    ],
    "company_b": [
        {
            "id": 3,
            "avatar": "https://develop.snipeitapp.com/uploads/avatars/3.jpg",
            "name": "Alison Gianotto",
            "first_name": "Alison",
            "last_name": "Gianotto",
            "username": "agianotto@grokability.com",
            "remote": False,
            "locale": "en-US",
            "employee_num": "9280",
            "manager": None,
            "jobtitle": "Arbitrator",
            "vip": False,
            "phone": "(215) 671-8482",
            "website": None,
            "address": "1770 Walker Forges Suite 580\nPort Lonnyfort, RI 35956-9785",
            "city": "East Helen",
            "state": "NV",
            "country": "Mongolia",
            "zip": "15923-4319",
            "email": "agianotto@grokability.com",
            "department": {
                "id": 6,
                "name": "Dept of Silly Walks",
            },
            "location": None,
            "notes": "Created by DB seeder",
            "permissions": {
                "superuser": "1",
            },
            "activated": True,
            "autoassign_licenses": True,
            "ldap_import": False,
            "two_factor_enrolled": False,
            "two_factor_optin": False,
            "assets_count": 7,
            "licenses_count": 1,
            "accessories_count": 0,
            "consumables_count": 0,
            "company": {
                "id": 1,
                "name": "Beier, Schumm and Upton",
            },
            "created_by": None,
            "created_at": {
                "datetime": "2024-04-26 09:42:05",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "updated_at": {
                "datetime": "2024-04-26 09:42:06",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "start_date": None,
            "end_date": None,
            "last_login": None,
            "deleted_at": None,
            "available_actions": {
                "update": True,
                "delete": False,
                "clone": True,
                "restore": False,
            },
            "groups": None,
        },
        {
            "id": 4,
            "avatar": "https://develop.snipeitapp.com/uploads/avatars/4.jpg",
            "name": "Afton Kris",
            "first_name": "Afton",
            "last_name": "Kris",
            "username": "boehm.sid",
            "remote": False,
            "locale": "en-US",
            "employee_num": "7457",
            "manager": None,
            "jobtitle": "Computer Programmer",
            "vip": False,
            "phone": "478-258-7137",
            "website": None,
            "address": "6010 Heaney Greens\nNew Soledad, UT 74152",
            "city": "Robelborough",
            "state": "AK",
            "country": "Rwanda",
            "zip": "88727-2261",
            "email": "sparisian@example.net",
            "department": {
                "id": 6,
                "name": "Dept of Silly Walks",
            },
            "location": None,
            "notes": "Created by DB seeder",
            "permissions": {
                "superuser": "1",
            },
            "activated": True,
            "autoassign_licenses": True,
            "ldap_import": False,
            "two_factor_enrolled": False,
            "two_factor_optin": False,
            "assets_count": 4,
            "licenses_count": 0,
            "accessories_count": 0,
            "consumables_count": 0,
            "company": {
                "id": 4,
                "name": "VonRueden-White",
            },
            "created_by": None,
            "created_at": {
                "datetime": "2024-04-26 09:42:05",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "updated_at": {
                "datetime": "2024-04-26 09:42:06",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "start_date": None,
            "end_date": None,
            "last_login": None,
            "deleted_at": None,
            "available_actions": {
                "update": True,
                "delete": False,
                "clone": True,
                "restore": False,
            },
            "groups": None,
        },
    ],
}

==> cartography-0.106.0.tar.gz: cartography-0.106.0/tests/data/snipeit/users.py <==
USERS = {
    "simpson_corp": [
        {
            "id": 1,
            "avatar": "https://develop.snipeitapp.com/uploads/avatars/1.jpg",
            "name": "Marge Simpson",
            "first_name": "Marge",
            "last_name": "Simpson",
            "username": "mbsimpson",
            "remote": False,
            "locale": "en-US",
            "employee_num": "12832",
            "manager": None,
            "jobtitle": "Occupational Therapist Aide",
            "vip": False,
            "phone": "+1.234.432.8715",
            "website": None,
            "address": "703 Jeramy Parkway Apt. 582\nTitusfurt, SC 30323",
            "city": "South Keven",
            "state": "MT",
            "country": "Tajikistan",
            "zip": "22367",
            "email": "mbsimpson@simpson.corp",
            "department": {
                "id": 3,
                "name": "Marketing",
            },
            "location": None,
            "notes": "Created by DB seeder",
            "permissions": {
                "superuser": "1",
            },
            "activated": True,
            "autoassign_licenses": True,
            "ldap_import": False,
            "two_factor_enrolled": False,
            "two_factor_optin": False,
            "assets_count": 7,
            "licenses_count": 1,
            "accessories_count": 0,
            "consumables_count": 0,
            "company": {
                "id": 2,
                "name": "Lind, Schroeder and Pacocha",
            },
            "created_by": None,
            "created_at": {
                "datetime": "2024-04-26 09:42:05",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "updated_at": {
                "datetime": "2024-04-26 09:42:05",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "start_date": None,
            "end_date": None,
            "last_login": None,
            "deleted_at": None,
            "available_actions": {
                "update": True,
                "delete": False,
                "clone": True,
                "restore": False,
            },
            "groups": None,
        },
        {
            "id": 2,
            "avatar": "https://develop.snipeitapp.com/uploads/avatars/2.jpg",
            "name": "Homer Simpson",
            "first_name": "Homer",
            "last_name": "Simpson",
            "username": "hjsimpson",
            "remote": False,
            "locale": "en-US",
            "employee_num": "30845",
            "manager": None,
            "jobtitle": "Transportation Worker",
            "vip": False,
            "phone": "785-362-4759",
            "website": None,
            "address": "7535 Bruen Junctions\nNorth Ceciliachester, VA 80961-3508",
            "city": "Breitenbergborough",
            "state": "ND",
            "country": "Gambia",
            "zip": "67260-1176",
            "email": "hjsimpson@simpson.corp",
            "department": {
                "id": 6,
                "name": "Dept of Silly Walks",
            },
            "location": None,
            "notes": "Created by DB seeder",
            "permissions": {
                "superuser": "1",
            },
            "activated": True,
            "autoassign_licenses": True,
            "ldap_import": False,
            "two_factor_enrolled": False,
            "two_factor_optin": False,
            "assets_count": 6,
            "licenses_count": 1,
            "accessories_count": 0,
            "consumables_count": 0,
            "company": {
                "id": 1,
                "name": "Beier, Schumm and Upton",
            },
            "created_by": None,
            "created_at": {
                "datetime": "2024-04-26 09:42:05",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "updated_at": {
                "datetime": "2024-04-26 09:42:05",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "start_date": None,
            "end_date": None,
            "last_login": None,
            "deleted_at": None,
            "available_actions": {
                "update": True,
                "delete": False,
                "clone": True,
                "restore": False,
            },
            "groups": None,
        },
    ],
    "south_park": [
        {
            "id": 3,
            "avatar": "https://develop.snipeitapp.com/uploads/avatars/3.jpg",
            "name": "Kyle Broflovski",
            "first_name": "Kyle",
            "last_name": "Broflovski",
            "username": "kbroflovski",
            "remote": False,
            "locale": "en-US",
            "employee_num": "9280",
            "manager": None,
            "jobtitle": "Arbitrator",
            "vip": False,
            "phone": "(215) 671-8482",
            "website": None,
            "address": "1770 Walker Forges Suite 580\nPort Lonnyfort, RI 35956-9785",
            "city": "East Helen",
            "state": "NV",
            "country": "Mongolia",
            "zip": "15923-4319",
            "email": "kbroflovski@south.park",
            "department": {
                "id": 6,
                "name": "Dept of Silly Walks",
            },
            "location": None,
            "notes": "Created by DB seeder",
            "permissions": {
                "superuser": "1",
            },
            "activated": True,
            "autoassign_licenses": True,
            "ldap_import": False,
            "two_factor_enrolled": False,
            "two_factor_optin": False,
            "assets_count": 7,
            "licenses_count": 1,
            "accessories_count": 0,
            "consumables_count": 0,
            "company": {
                "id": 1,
                "name": "Beier, Schumm and Upton",
            },
            "created_by": None,
            "created_at": {
                "datetime": "2024-04-26 09:42:05",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "updated_at": {
                "datetime": "2024-04-26 09:42:06",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "start_date": None,
            "end_date": None,
            "last_login": None,
            "deleted_at": None,
            "available_actions": {
                "update": True,
                "delete": False,
                "clone": True,
                "restore": False,
            },
            "groups": None,
        },
        {
            "id": 4,
            "avatar": "https://develop.snipeitapp.com/uploads/avatars/4.jpg",
            "name": "Eric Cartman",
            "first_name": "Eric",
            "last_name": "Cartman",
            "username": "ecartman",
            "remote": False,
            "locale": "en-US",
            "employee_num": "7457",
            "manager": None,
            "jobtitle": "Computer Programmer",
            "vip": False,
            "phone": "478-258-7137",
            "website": None,
            "address": "6010 Heaney Greens\nNew Soledad, UT 74152",
            "city": "Robelborough",
            "state": "AK",
            "country": "Rwanda",
            "zip": "88727-2261",
            "email": "ecartman@south.park",
            "department": {
                "id": 6,
                "name": "Dept of Silly Walks",
            },
            "location": None,
            "notes": "Created by DB seeder",
            "permissions": {
                "superuser": "1",
            },
            "activated": True,
            "autoassign_licenses": True,
            "ldap_import": False,
            "two_factor_enrolled": False,
            "two_factor_optin": False,
            "assets_count": 4,
            "licenses_count": 0,
            "accessories_count": 0,
            "consumables_count": 0,
            "company": {
                "id": 4,
                "name": "VonRueden-White",
            },
            "created_by": None,
            "created_at": {
                "datetime": "2024-04-26 09:42:05",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "updated_at": {
                "datetime": "2024-04-26 09:42:06",
                "formatted": "Fri Apr 26, 2024 9:42AM",
            },
            "start_date": None,
            "end_date": None,
            "last_login": None,
            "deleted_at": None,
            "available_actions": {
                "update": True,
                "delete": False,
                "clone": True,
                "restore": False,
            },
            "groups": None,
        },
    ],
}
